;An Agent-Based Model of Corruption as a Cellular Automaton
;Author: Warren Vierheller
;Date: May 28, 2018
;Korea University
;Code is built off of "An Agent-based Model of Corruption"
;By Valery Dzusati (2015) as adapted from Ross A. Hammond (2009)
;https://github.com/chermen/corruption2015

;Code modifications to the original model are denoted by initials of the contributor. e.g. '-WV' for Warren Vierheller and '-AI' for Dr. Alan Isaac
;Original variable names are listed with 'varname:' e.g. 'varname: x' denotes that x is the variable in the paper for payoffCorrupt
;;;;;;Variables and Attributes;;;;;;

globals [
  nearby              ;(list) used in order to help setupNeighborhood procedure -WV
  corruptRatioDecimal ;(float) alt. corrupt ratio converted to a decimal for easier comparison -WV
  jailPopulation      ;(int) jail population.


;;Sliders;; jail-term/ counter/ memory have been changed to globals to increase readibility -WV
  ;jailTerm           ;(int)number of rounds excluded from game
  ;counter            ;(int)the counter of being turned in for corruption
  ;density            ;(int)sets up total citizen population by determing (% of land occupied by a household)  -WV
  ;govtPerCapita      ;(int) determines approximately how many bureaucrats exist per 1000 citizen
  ;numBureaucrats     ;(int)number of bureaucrats within the model.
  ;avgHonestyDisp     ;(int)average honesty disposition of agent !!!maybe include seperate slider for breeds !!!change to float
  ;stdDevHonestyDisp  ;(int)standard deviation of honesty dispostion
                      ;avgHonestyDisp and stdHonestyDisp are modified from the number-of-corrupt-agent slider - WV
  ;neighborhoodSize   ;(int)size of each citizen's neighborhood in terms of its radius -WV
  ;corruptCitizens    ;(float) initial proportion of corrupt citizens. modified from static no. -WV
  ;corruptBureaucrats ;(float) initial % of corrupt bureaucrats. modified so bureaucrats and citizens have seperate sliders. -WV
  ;crimeReports       ;(int) measures the about of reports needed before a conviction is lobbied against the corruption agent -WV
  ;payoffCorrupt      ;payoff for being corrupt. varname: x
  ;payoffNonCorrupt   ;payoff for being non-corrupt.  varname: y

;;Switches;;

]

breed [ citizens citizen ]
breed [ bureaucrats bureaucrat]

patches-own [ ]

turtles-own [
  honestyDisp   ;(float) modified from original model to include only 5 levels (0,.25,...1) -WV
  neighborhood  ;(list) each citizen has a (Moore) neighborhood of nearby citizens. bureaucrats neighborhood include all other bureaucrats.-WV
  memory        ;(list) memory of previous interactions with corrupt agents
  gameplay?     ;(bool)show whether the agent played the game in this round
  active?       ;(bool)show whether in jail or not, "active? false" stands for being in jail
  counter       ;(int)the counter of being turned in for corruption !!!!ALLOW COUNTER TO EXPIRE OVER TIME
  corrupt?      ;(bool)determines whether or not a turtle was corrupt last round. same as the red/white GUI representation in original model. -WV
  jailSentence  ;(int)if arrested an agent must serve a jail sentence equal to the designated jail term
  myDecisions   ;(list) determination of turtles past decisions. Used to determine if changes in personal decisionmaking -WV
  noChange      ;(bool) determines if turtles have made consistent decisions over the last 10 ticks -WV
]

citizens-own [
  myBureaucrat  ;(agentset) each citizen reports to a single bureaucrat (the closest one) throughout a single iteration -WV
                ;however if a bureaucrat is jailed, a citizen will be assigned the next closest bureaucrat until he is released
]

bureaucrats-own [ ]


;;;;;;Setup Procedures;;;;;;

to startup  ;set values to baseline scenario on startup -WV
  set payoffCorrupt 20
  set payoffNonCorrupt 1
  set avgHonestyDisp 0.5
  set stdDevHonestyDisp 0.5
  set memoryLength 5
  set neighborhoodSize 1
  set jailTerm 2
  set crimeReports 2
  set corruptCitizens 0.9
  set corruptBureaucrats 0.9
  set density 75
  set neighborhoodInfluence? True
  set govtOffice 15
  set govtPerCapita 51
  set enforcement? true
end

to setup
  ca
  random-seed behaviorspace-run-number ; sets the seed at incremental levels to allow replicative experiments
  setupGlobals
  setupPatches
  setupCitizens
  setupBureaucrats
  setupNeighborhood
  setupGUI
  updateGUI
  reset-ticks
end

to setupGlobals
end


to setupPatches
  ask patches [set pcolor 1] ;provides better contrast of agent color against patch color
end

to setupBureaucrats
  let citizenPop count citizens
  let govtdensity govtPerCapita / 1000
  let numGovt citizenPop * govtdensity
  let numPerOffice numGovt / govtOffice
  ask n-of govtOffice patches [
    sprout-bureaucrats numPerOffice [
      estBaseAttributes
      set shape "circle-x" ;setting up agent-GUI features here allows for smoother set up -WV
      set color scale-color yellow honestyDisp 0 1
      if any? citizens-here = true [ask citizens-here [die]]  ;prevents citizen and bureaucrat from occupying same space
      ]
    ]
  let n count bureaucrats
  ask n-of (corruptBureaucrats * n) bureaucrats [set corrupt? true] ;a certain percentage of bureaucrats begin corrupt
end

to setupCitizens
    ask patches [
    if random 100 < density [
      sprout-citizens 1 [
      move-to patch-here ;places agents on center of patch -WV
      estBaseAttributes
      set shape "square"
      set color scale-color sky honestyDisp 0 1
      ]
    ]
  ]
    let n count citizens
  ask n-of (corruptCitizens * n) citizens [set corrupt? true] ;a certain percentage of citizens begin corrupt
end

to estBaseAttributes ;sets up common turtle attributes -WV
  set honestyDisp random-normal avgHonestyDisp stdDevHonestyDisp ;set starting honestyDisp of agents. modified from original 0 to 1 float
  if (honestyDisp > 1) [set honestyDisp 1]  ;honestyDisp cannot go above the upper limit of 5
  if (honestyDisp < 0) [set honestyDisp 0]  ;honestyDisp cannot go below the lower limit of 0
  set active? true     ;everyone is free, not in jail
  set gameplay? false  ;no one has played the game yet
  set corrupt? false ;no one is yet corrupt. changes in next line -WV
  set noChange false ;turtles inititally have not made any decisions -WV
  set memory n-values memoryLength [-> random 2] ;streamlined from original model -AI
  set myDecisions n-values 10 [-> random 2] ; streamlined from original model -AI
end

to setupNeighborhood ;establishes agents' neighborhood -WV
  ask citizens [
    set nearby mooreNeighborhood neighborhoodSize ;(list) reports coordinates of patches within a specified radius -WV
    set neighborhood citizens at-points nearby ;establishes citizens' neighborhood as agents within a designated raidus -WV
  ]
  ask bureaucrats [set neighborhood other bureaucrats-here]   ;establishes bureaucratic neighborhood as all other bureaucrats
end


to-report mooreNeighborhood [n] ;list the coordinates of all patches within a certain area of the agent who calls on it -WV
  let result [list pxcor pycor] of patches with [abs pxcor <= n and abs pycor <= n]
  report remove [0 0] result ;neighborhood does not include the patch where the turtle resides
;Wilensky, U. (1997). NetLogo Moore & Von Neuman Example.
;http://ccl.northwestern.edu/netlogo/models/Moore&VonNeumannExample.
;Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.
end

to-report nearestBureaucrat ;reports random bureaucrat at closest govt office -WV
  report min-one-of bureaucrats [distance myself]
end

to setupGUI
  resize-world -17 17 -17 17   ;resize world so that total no. of patches is 1225 -WV
                               ;location of origin needs to be center in order for setupNeighborhood procedure to properly function -WV
  set-patch-size 12
  ask links [set hidden? true] ;links are hidden for better visibility -WV
end


;;;;;;;Go Procedures;;;;;;

to go
  if ticks = 100 [stop] ;most test runs find that the model stabilizes within the first 50 ticks. -WV
  updateBureaucrats
  updateCitizens
  if all? turtles [noChange = true] [stop] ;stops program if all turtles have made the same decision over the last 10 ticks
  trackChange
  plotJailPop
  plotCorruption
  tick
  updateGUI
end



to sumDecisions ;used to determine if no changes are occuring in the model -WV
  let totalDecisions sum myDecisions
  set noChange ifelse-value (0 = totalDecisions or 10 = totalDecisions) [true][false] ;-WV/ AI
end

to updateBureaucrats
  ask bureaucrats [
    sumDecisions
    set gameplay? false
    ifelse (active? = true and gameplay? = false)
    [
      decide
      set gameplay? true
      alterDisp
    ][
      serveJailSent
    ]
  ]
end

to updateCitizens
  ask citizens [
    sumDecisions
    set gameplay? false
    ifelse (active? = true and gameplay? = false)
    [
      if any? bureaucrats with [corrupt? = false][  ;if all bureaucrats in jail, citizens do not interact this turn.
      decide     ;model altered so that agents decide before interacting -WV
                 ;deciding before interacting is more intuitive and follows Hammond's original intended model
      interact
      updateMemory ;updates memory for  both citizens and bureaucrats -WV
      if enforcement? [enforce]    ;altered from original model to occur before calculatePayoff in order to avoid double payout
      set gameplay? true
      alterDisp
      ]
    ][
      serveJailSent
    ]
  ]
end




to decide    ;(bool) agents decide to be corrupt or non-corruption
             ;based on Hammond's equation (1 - B)[A*x_i+(1-A)*y]+B*[y-k*y]
  let myCorruptPayoff (((1 - chanceofJail) * ((encounterCorruptAgent * agentPayoff) + ((1 - encounterCorruptAgent) * payoffNonCorrupt)))
  + (chanceofJail * (payoffNonCorrupt - (jailterm * payoffNonCorrupt))))
  ifelse myCorruptPayoff > payoffNonCorrupt ;ifelse x_p > y
  [set corrupt? true]
  [set corrupt? false]
end


to-report agentPayoff ;agent's perceived payoff from corruption. varname: x_i
  report ((1 - honestyDisp) * payoffCorrupt)
end

to-report encounterCorruptAgent ;perceived likelihood of encountering a corrupt agent. varname: A = n / N
  report (sum memory / memoryLength)
end

to-report chanceOfJail ;perceived chance of being caught for a corruption action this round. varname: B = m / M
                       ;altered from original to include neighbors instead of static network and always excludes oneself
  let neighborsInJail count neighborhood with [active? = false]
  let corruptNeighbors count neighborhood with [corrupt?]
  report ifelse-value (corruptNeighbors = 0) ;can't divide by zero
  [0]
  [neighborsinJail / corruptNeighbors]

end

to interact  ;actual governmental interaction between citizen and bureaucrat
  set myBureaucrat nearestBureaucrat  ;citizens will interact with the nearest active bureaucrat
  ;ai: indent `if` bodies
  if ([corrupt?] of myBureaucrat = true) and ([corrupt?] of self = false) ;bureaucrat increases counter by 1
  [ask myBureaucrat [set counter (counter + 1)]]
  if ([corrupt?] of myBureaucrat = false) and ([corrupt?] of self = true) ;citizen increases counter by 1
  [set counter (counter + 1)]
end

to updateMemory          ;updates memory of past corrupt. originally part of interact procedure -WV
  ifelse [corrupt?] of myBureaucrat = true
      [ask self          ;citizens updates experience with corruption based on bureaucratic action (corrupt or non) -WV
          [set memory fput 1 memory
          set memory but-last memory] ;streamlined from original model -WV
      ]
      [ask self
        [set memory fput 0 memory
          set memory but-last memory
          ]
      ]
  ifelse [corrupt?] of self = true
      [ask myBureaucrat   ;bureaucrats update experience with corruption based on citizen action (corrupt or non) -WV
        [set memory fput 1 memory
          set memory but-last memory
        ]
      ]
      [ask myBureaucrat
        [set memory fput 0 memory
          set memory but-last memory
    ]
      ]
end



to enforce ; put suspect in jail after specified turn-ins to the authorities
  if (counter >= crimeReports)
    [
      set active? false
      set corrupt? false
    ]
end


to alterDisp ;when not in jail, agents alter honesty disposition within so that it  better reflects their neighborhood average -WV
  if neighborhoodInfluence? [
  if any? neighborhood[
  let neighborHonesty mean [honestyDisp] of neighborhood
  if [honestyDisp] of self > (neighborHonesty + honestyChange) [set honestyDisp (honestyDisp - honestyChange)] ;decease honestyDisp by 0.20
  if [honestyDisp] of self < (neighborHonesty - honestyChange) [set honestyDisp (honestyDisp + honestyChange)] ;increase honestyDisp by 0.20
  if ([honestyDisp] of self < (neighborHonesty + honestyChange)) and ([honestyDisp] of self > (neighborHonesty - honestyChange)) ;set honestyDistp to average
      [set honestyDisp neighborHonesty]
  ]
 ]
end

to serveJailSent ;serve jail sentence and release upon finishing.
    if active? = false [
    ifelse jailSentence >= jailTerm [
      set active? true
      set counter 0  ;reset counter
      set jailSentence 0 ;reset counter for jailSentence
      set corrupt? false ;released agents initially come out with a non-corrupt strategy
    ][
      set jailSentence (jailSentence + 1)
    ]
   ]
end

to trackChange
  ask citizens [
    let N 10 ;set N as the oldest position in the memoryLength list
  ifelse [corrupt?] of self = true
      [ask self          ;citizens updates experience with corruption based on bureaucratic action (corrupt or non) -WV
          [set myDecisions fput 1 myDecisions
          set myDecisions remove-item N myDecisions]
      ]
      [ask self
        [set myDecisions fput 0 myDecisions
          set myDecisions remove-item N myDecisions
          ]
      ]
  ifelse [corrupt?] of myBureaucrat = true
      [ask myBureaucrat   ;bureaucrats update experience with corruption based on citizen action (corrupt or non) -WV
        [set myDecisions fput 1 myDecisions
          set myDecisions remove-item N myDecisions
        ]
      ]
      [ask myBureaucrat
        [set myDecisions fput 0 myDecisions
          set myDecisions remove-item N myDecisions
    ]
      ]
  ]
end


to updateGUI
  ask patches [
    ifelse any? turtles-here with [corrupt? = true][  ;creates a red outline around agents to indicate they have recently been corrupt
      set pcolor red
    ][
     set pcolor 1
    ]
  ]
  ask citizens [set color scale-color sky honestyDisp 0 1]
  ask bureaucrats [set color scale-color yellow honestyDisp 0 1]
end

;;;;;Misc Reporters;;;;

to-report corruption ;% of the population considered corrupt -WV
  let aggCorruption count turtles with [corrupt? = true]
  let totPop count turtles
  report  (aggCorruption / totPop) * 100
end

to-report corruptionRatio; avg [u/l] ratio to determine sparsity within a model using Moore neighborhood makeup (r = 1) -WV
  let totalCorruption 0
  let citizenCorruptionRatio 0
  let bureaucratCorruptionRatio 0
  let likeNeighbors 0
  let unlikeNeighbors 0
  ask citizens[
    let immediateNeighbors citizens-on neighbors
    set likeNeighbors likeNeighbors + (count immediateNeighbors with [corrupt? = [corrupt?] of myself])
    set unlikeNeighbors unlikeNeighbors + (count immediateNeighbors with [corrupt? != [corrupt?] of myself])
  ]
  ask bureaucrats [
    set likeNeighbors likeNeighbors + (count neighborhood with [corrupt? = [corrupt?] of myself])
    set unlikeNeighbors unlikeNeighbors + (count neighborhood with [corrupt? != [corrupt?] of myself])
  ]
  report (word unlikeNeighbors  ":"  likeNeighbors)
  set corruptRatioDecimal unlikeNeighbors / likeNeighbors
end

to-report corruptionDensitySparse ;alt. density measure only for citizens -WV
  let sparseCluster 0
  ask citizens [
    let immediateNeighbors citizens-on neighbors
    let similarNeighbors count immediateNeighbors with [corrupt?]
    if similarNeighbors > 3 [set sparseCluster sparseCluster + 1]
  ]
  report sparseCluster
end

to-report corruptionDensityCompact ;alternative density measure only for citizens -WV
   let compactCluster 0
  ask citizens [
    let immediateNeighbors citizens-on neighbors
    let similarNeighbors count immediateNeighbors with [corrupt?]
    if similarNeighbors > 4 [set compactCluster compactCluster + 1]
  ]
  report compactCluster
end

to-report jailPop
  let aggPrisoners count turtles with [active? = false]
  let totPop count turtles
  report (aggPrisoners / totPop) * 100
end


;;;;;;Test Procedures;;;;;

to testSetup
  ifelse (1200 != count patches) and (any? patches with [pcolor != 1])
    [error "Setup Error: Patches"]
    [ print "Patches Good"]
  ifelse all? patches [
    (1 < count citizens-here) and (1 < count bureaucrats-here) ]
    [error "Setup Error: Turtles"]
    [print "Turtles Good"]
  ifelse (payoffCorrupt < payoffNonCorrupt)
    [error "Setup Error: payoffCorrupt must be at least as large as payoffNonCorrupt"]
    [print "Payoff Values Good"]
end


;;;;;;Plot and Data Procedures;;;;;;

to plotJailPop  ;plot percentage of the population in jail -WV
  set-current-plot "Jail Population"
  let aggPrisoners count turtles with [active? = false]
  let totPop count turtles
  plot (aggPrisoners / totPop) * 100
  set jailPopulation (aggPrisoners / totPop) * 100
end

to plotCorruption
  set-current-plot "Corruption"
  let aggCorruption count turtles with [corrupt? = true]
  let totPop count turtles
  plot  (aggCorruption / totPop) * 100
end

to-report numCorruptBureaucrats
  let aggCorruptBureaucrats count bureaucrats with [corrupt? = true]
  let totBureaucrats count bureaucrats
  report aggCorruptBureaucrats / totBureaucrats
end

to-report numCorruptCitizens
  let aggCorruptCitizens count citizens with [corrupt? = true]
  let totCitizens count citizens
  report aggCorruptCitizens / totCitizens
end
@#$#@#$#@
GRAPHICS-WINDOW
210
10
638
439
-1
-1
12.0
1
10
1
1
1
0
0
0
1
-17
17
-17
17
0
0
1
ticks
30.0

SLIDER
23
58
195
91
density
density
0
100
75.0
1
1
%
HORIZONTAL

SLIDER
24
101
196
134
avgHonestyDisp
avgHonestyDisp
0
1
0.5
.25
1
NIL
HORIZONTAL

BUTTON
29
185
95
218
NIL
Setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
126
185
189
218
NIL
Go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
24
142
198
175
stdDevHonestyDisp
stdDevHonestyDisp
0
1
0.5
.25
1
NIL
HORIZONTAL

SLIDER
23
335
195
368
memoryLength
memoryLength
1
100
5.0
1
1
NIL
HORIZONTAL

SLIDER
23
381
195
414
jailTerm
jailTerm
0
10
2.0
1
1
NIL
HORIZONTAL

SLIDER
23
251
195
284
payoffCorrupt
payoffCorrupt
10
20
20.0
1
1
NIL
HORIZONTAL

SLIDER
23
291
195
324
payoffNonCorrupt
payoffNonCorrupt
1
10
1.0
1
1
NIL
HORIZONTAL

SLIDER
649
228
821
261
neighborhoodSize
neighborhoodSize
0
5
1.0
1
1
NIL
HORIZONTAL

SLIDER
648
190
820
223
corruptCitizens
corruptCitizens
0
1
0.9
.1
1
NIL
HORIZONTAL

SLIDER
649
45
823
78
corruptBureaucrats
corruptBureaucrats
0
1
0.9
.1
1
NIL
HORIZONTAL

SLIDER
648
89
951
122
govtPerCapita
govtPerCapita
0
100
51.0
1
1
workers per 1000 citizens
HORIZONTAL

SLIDER
22
424
194
457
crimeReports
crimeReports
0
10
2.0
1
1
NIL
HORIZONTAL

PLOT
643
386
848
583
Jail Population
NIL
% of prisoners in pop.
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"pen-0" 1.0 0 -16777216 true "" "plot jailPop"

PLOT
866
390
1090
584
Corruption
NIL
% of corruption in pop.
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"pen-0" 1.0 0 -16777216 true "" "plot corruption\n"

SWITCH
20
466
202
499
neighborhoodInfluence?
neighborhoodInfluence?
0
1
-1000

SLIDER
647
130
819
163
govtOffice
govtOffice
1
20
15.0
1
1
NIL
HORIZONTAL

TEXTBOX
829
289
979
307
Monitors
13
0.0
1

TEXTBOX
649
21
799
39
Bureaucrat Modifiers
13
0.0
1

TEXTBOX
649
170
799
188
Citizen Modifiers
13
0.0
1

TEXTBOX
28
32
178
50
General Setup Variables
13
0.0
1

TEXTBOX
28
231
189
263
Agent Decision Modifiers
13
0.0
1

MONITOR
646
328
763
373
Corruption Ratio
corruptionRatio
3
1
11

MONITOR
781
327
891
372
Sparse Clusters
corruptionDensitySparse
17
1
11

MONITOR
904
327
1028
372
Compact Clusters
corruptionDensityCompact
17
1
11

SWITCH
22
515
163
548
enforcement?
enforcement?
0
1
-1000

SLIDER
20
561
192
594
honestyChange
honestyChange
0
1
0.2
0.1
1
NIL
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

circle-x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
Circle -13840069 false false 8 8 283

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113
@#$#@#$#@
NetLogo 6.0.2
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment" repetitions="35" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>corruption</metric>
    <metric>behaviorspace-run-number</metric>
    <metric>jailPopulation</metric>
    <enumeratedValueSet variable="crimeReports">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="density">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stdDevHonestyDisp">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="avgHonestyDisp">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neighborhoodInfluence?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memoryLength">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="payoffNonCorrupt">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="govtOffice">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="corruptCitizens">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="payoffCorrupt">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neighborhoodSize">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="govtPerCapita">
      <value value="51"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="corruptBureaucrats">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="jailTerm">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enforcement?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FirstDraftParameterSweep" repetitions="5" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>corruption</metric>
    <metric>corruptionRatio</metric>
    <metric>corruptionDensityCompact</metric>
    <metric>CorruptionDensitySparse</metric>
    <metric>JailPop</metric>
    <metric>numCorruptCitizens</metric>
    <metric>numCorruptBureaucrats</metric>
    <enumeratedValueSet variable="crimeReports">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="density">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stdDevHonestyDisp">
      <value value="0.2"/>
    </enumeratedValueSet>
    <steppedValueSet variable="avgHonestyDisp" first="0.25" step="0.25" last="1"/>
    <enumeratedValueSet variable="neighborhoodInfluence?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memoryLength">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="payoffNonCorrupt">
      <value value="1"/>
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="govtOffice">
      <value value="5"/>
      <value value="10"/>
      <value value="15"/>
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="corruptCitizens">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enforcement?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="govtPerCapita">
      <value value="51"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neighborhoodSize">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="payoffCorrupt">
      <value value="10"/>
      <value value="15"/>
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="corruptBureaucrats">
      <value value="0.5"/>
    </enumeratedValueSet>
    <steppedValueSet variable="jailTerm" first="1" step="1" last="5"/>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
